import { ActionCodeInfo, ActionCodeSettings, ApplicationVerifier, Auth, AuthCredential, AuthError, AuthProvider, ConfirmationResult, PhoneAuthCredential, PopupRedirectResolver, User, UserCredential } from "@firebase/auth";
import { UseMutationOptions, UseMutationResult } from "react-query";
export declare function useAuthApplyActionCode(auth: Auth, useMutationOptions?: UseMutationOptions<void, AuthError, string>): UseMutationResult<void, AuthError, string>;
export declare function useAuthCheckActionCode(auth: Auth, useMutationOptions?: UseMutationOptions<ActionCodeInfo, AuthError, string>): UseMutationResult<ActionCodeInfo, AuthError, string>;
export declare function useAuthConfirmPasswordReset(auth: Auth, useMutationOptions?: UseMutationOptions<void, AuthError, {
    oobCode: string;
    newPassword: string;
}>): UseMutationResult<void, AuthError, {
    oobCode: string;
    newPassword: string;
}>;
export declare function useAuthCreateUserWithEmailAndPassword(auth: Auth, useMutationOptions?: UseMutationOptions<UserCredential, AuthError, {
    email: string;
    password: string;
}>): UseMutationResult<UserCredential, AuthError, {
    email: string;
    password: string;
}>;
export declare function useAuthDeleteUser(useMutationOptions?: UseMutationOptions<void, AuthError, User>): UseMutationResult<void, AuthError, User>;
export declare function useAuthLinkWithCredential(useMutationOptions?: UseMutationOptions<UserCredential, AuthError, {
    user: User;
    credential: AuthCredential;
}>): UseMutationResult<UserCredential, AuthError, {
    user: User;
    credential: AuthCredential;
}>;
export declare function useAuthLinkWithPhoneNumber(useMutationOptions?: UseMutationOptions<ConfirmationResult, AuthError, {
    user: User;
    phoneNumber: string;
    appVerifier: ApplicationVerifier;
}>): UseMutationResult<ConfirmationResult, AuthError, {
    user: User;
    phoneNumber: string;
    appVerifier: ApplicationVerifier;
}>;
export declare function useAuthLinkWithPopup(useMutationOptions?: UseMutationOptions<UserCredential, AuthError, {
    user: User;
    provider: AuthProvider;
    resolver?: PopupRedirectResolver;
}>): UseMutationResult<UserCredential, AuthError, {
    user: User;
    provider: AuthProvider;
    resolver?: PopupRedirectResolver;
}>;
export declare function useAuthLinkWithRedirect(useMutationOptions?: UseMutationOptions<never, AuthError, {
    user: User;
    provider: AuthProvider;
    resolver?: PopupRedirectResolver;
}>): UseMutationResult<never, AuthError, {
    user: User;
    provider: AuthProvider;
    resolver?: PopupRedirectResolver;
}>;
export declare function useAuthReauthenticateWithCredential(useMutationOptions?: UseMutationOptions<UserCredential, AuthError, {
    user: User;
    credential: AuthCredential;
}>): UseMutationResult<UserCredential, AuthError, {
    user: User;
    credential: AuthCredential;
}>;
export declare function useAuthReauthenticateWithPhoneNumber(useMutationOptions?: UseMutationOptions<ConfirmationResult, AuthError, {
    user: User;
    phoneNumber: string;
    appVerifier: ApplicationVerifier;
}>): UseMutationResult<ConfirmationResult, AuthError, {
    user: User;
    phoneNumber: string;
    appVerifier: ApplicationVerifier;
}>;
export declare function useAuthReauthenticateWithPopup(useMutationOptions?: UseMutationOptions<UserCredential, AuthError, {
    user: User;
    provider: AuthProvider;
    resolver?: PopupRedirectResolver;
}>): UseMutationResult<UserCredential, AuthError, {
    user: User;
    provider: AuthProvider;
    resolver?: PopupRedirectResolver;
}>;
export declare function useAuthReauthenticateWithRedirect(useMutationOptions?: UseMutationOptions<never, AuthError, {
    user: User;
    provider: AuthProvider;
    resolver?: PopupRedirectResolver;
}>): UseMutationResult<never, AuthError, {
    user: User;
    provider: AuthProvider;
    resolver?: PopupRedirectResolver;
}>;
export declare function useAuthReload(useMutationOptions?: UseMutationOptions<void, AuthError, User>): UseMutationResult<void, AuthError, User>;
export declare function useAuthSendEmailVerification(useMutationOptions?: UseMutationOptions<void, AuthError, {
    user: User;
    actionCodeSettings?: ActionCodeSettings | null;
}>): UseMutationResult<void, AuthError, {
    user: User;
    actionCodeSettings?: ActionCodeSettings | null;
}>;
export declare function useAuthSendPasswordResetEmail(auth: Auth, useMutationOptions?: UseMutationOptions<void, AuthError, {
    email: string;
    actionCodeSettings?: ActionCodeSettings;
}>): UseMutationResult<void, AuthError, {
    email: string;
    actionCodeSettings?: ActionCodeSettings;
}>;
export declare function useAuthSendSignInLinkToEmail(auth: Auth, useMutationOptions?: UseMutationOptions<void, AuthError, {
    email: string;
    actionCodeSettings: ActionCodeSettings;
}>): UseMutationResult<void, AuthError, {
    email: string;
    actionCodeSettings: ActionCodeSettings;
}>;
export declare function useAuthSignInAnonymously(auth: Auth, useMutationOptions?: UseMutationOptions<UserCredential, AuthError, {
    email: string;
    password: string;
}>): UseMutationResult<UserCredential, AuthError, {
    email: string;
    password: string;
}>;
export declare function useAuthSignInWithCredential(auth: Auth, useMutationOptions?: UseMutationOptions<UserCredential, AuthError, AuthCredential>): UseMutationResult<UserCredential, AuthError, AuthCredential>;
export declare function useAuthSignInWithCustomToken(auth: Auth, useMutationOptions?: UseMutationOptions<UserCredential, AuthError, string>): UseMutationResult<UserCredential, AuthError, string>;
export declare function useAuthSignInWithEmailAndPassword(auth: Auth, useMutationOptions?: UseMutationOptions<UserCredential, AuthError, {
    email: string;
    password: string;
}>): UseMutationResult<UserCredential, AuthError, {
    email: string;
    password: string;
}>;
export declare function useAuthSignInWithEmailLink(auth: Auth, useMutationOptions?: UseMutationOptions<UserCredential, AuthError, {
    email: string;
    emailLink?: string;
}>): UseMutationResult<UserCredential, AuthError, {
    email: string;
    emailLink?: string;
}>;
export declare function useAuthSignInWithPhoneNumber(auth: Auth, useMutationOptions?: UseMutationOptions<ConfirmationResult, AuthError, {
    phoneNumber: string;
    appVerifier: ApplicationVerifier;
}>): UseMutationResult<ConfirmationResult, AuthError, {
    phoneNumber: string;
    appVerifier: ApplicationVerifier;
}>;
export declare function useAuthSignInWithPopup(auth: Auth, useMutationOptions?: UseMutationOptions<UserCredential, AuthError, {
    provider: AuthProvider;
    resolver?: PopupRedirectResolver;
}>): UseMutationResult<UserCredential, AuthError, {
    provider: AuthProvider;
    resolver?: PopupRedirectResolver;
}>;
export declare function useAuthSignInWithRedirect(auth: Auth, useMutationOptions?: UseMutationOptions<never, AuthError, {
    provider: AuthProvider;
    resolver?: PopupRedirectResolver;
}>): UseMutationResult<never, AuthError, {
    provider: AuthProvider;
    resolver?: PopupRedirectResolver;
}>;
export declare function useAuthSignOut(auth: Auth, useMutationOptions?: UseMutationOptions<void, AuthError, void>): UseMutationResult<void, AuthError, void>;
export declare function useAuthUnlink(useMutationOptions?: UseMutationOptions<User, AuthError, {
    user: User;
    providerId: string;
}>): UseMutationResult<User, AuthError, {
    user: User;
    providerId: string;
}>;
export declare function useAuthUpdateCurrentUser(auth: Auth, useMutationOptions?: UseMutationOptions<void, AuthError, User | null>): UseMutationResult<void, AuthError, User | null>;
export declare function useAuthUpdateEmail(useMutationOptions?: UseMutationOptions<void, AuthError, {
    user: User;
    newEmail: string;
}>): UseMutationResult<void, AuthError, {
    user: User;
    newEmail: string;
}>;
export declare function useAuthUpdatePassword(useMutationOptions?: UseMutationOptions<void, AuthError, {
    user: User;
    newPassword: string;
}>): UseMutationResult<void, AuthError, {
    user: User;
    newPassword: string;
}>;
export declare function useAuthUpdatePhoneNumber(useMutationOptions?: UseMutationOptions<void, AuthError, {
    user: User;
    credential: PhoneAuthCredential;
}>): UseMutationResult<void, AuthError, {
    user: User;
    credential: PhoneAuthCredential;
}>;
export declare function useAuthUpdateProfile(useMutationOptions?: UseMutationOptions<void, AuthError, {
    user: User;
    displayName?: string | null;
    photoURL?: string | null;
}>): UseMutationResult<void, AuthError, {
    user: User;
    displayName?: string | null;
    photoURL?: string | null;
}>;
export declare function useAuthVerifyBeforeUpdateEmail(useMutationOptions?: UseMutationOptions<void, AuthError, {
    user: User;
    newEmail: string;
    actionCodeSettings?: ActionCodeSettings;
}>): UseMutationResult<void, AuthError, {
    user: User;
    newEmail: string;
    actionCodeSettings?: ActionCodeSettings;
}>;
export declare function useAuthVerifyPasswordResetCode(auth: Auth, useMutationOptions?: UseMutationOptions<string, AuthError, string>): UseMutationResult<string, AuthError, string>;
